# *** IMPORTS *** #
from distutils.core import setup

# *** SETUP *** #
setup(
	name = 'alexkar7_py_helloworld',
	packages = ['alexkar7_py_helloworld'],
	version = '0.1',
	description = 'A simple Python program greeting you',
	author = 'Alejandro Carmona Mejia',
	author_email = 'alejandro.carmonamejia@gmail.com',
	url = 'https://github.com/alexkar7/alexkar7_py_helloworld',
	download_url = 'https://github.com/alexkar7/alexkar7_py_helloworld/archive/0.1.tar.gz',
	keywords = ['testing', 'greetings', 'example'], 
	classifiers = [],
)
